.. relatorio documentation master file, created by
   sphinx-quickstart on Wed Jun 24 12:26:14 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to relatorio's documentation!
=====================================

Contents:

.. toctree::
   :maxdepth: 2

   quickexample
   indepthexample
